Struct amazon_sp_fulfillment_inbound::models::transport_detail_input::TransportDetailInput
source · [−]pub struct TransportDetailInput {
pub partnered_small_parcel_data: Option<Box<PartneredSmallParcelDataInput>>,
pub non_partnered_small_parcel_data: Option<Box<NonPartneredSmallParcelDataInput>>,
pub partnered_ltl_data: Option<Box<PartneredLtlDataInput>>,
pub non_partnered_ltl_data: Option<Box<NonPartneredLtlDataInput>>,
}Expand description
TransportDetailInput : Information required to create an Amazon-partnered carrier shipping estimate, or to alert the Amazon fulfillment center to the arrival of an inbound shipment by a non-Amazon-partnered carrier.
Fields
partnered_small_parcel_data: Option<Box<PartneredSmallParcelDataInput>>non_partnered_small_parcel_data: Option<Box<NonPartneredSmallParcelDataInput>>partnered_ltl_data: Option<Box<PartneredLtlDataInput>>non_partnered_ltl_data: Option<Box<NonPartneredLtlDataInput>>Implementations
sourceimpl TransportDetailInput
impl TransportDetailInput
sourcepub fn new() -> TransportDetailInput
pub fn new() -> TransportDetailInput
Information required to create an Amazon-partnered carrier shipping estimate, or to alert the Amazon fulfillment center to the arrival of an inbound shipment by a non-Amazon-partnered carrier.